Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(557)

Unified Diff: runtime/vm/class_finalizer.cc

Issue 8403003: Rename the VM internal 'var' type to 'Dynamic' type. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: '' Created 9 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/ast_test.cc ('k') | runtime/vm/code_generator_ia32.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/class_finalizer.cc
===================================================================
--- runtime/vm/class_finalizer.cc (revision 778)
+++ runtime/vm/class_finalizer.cc (working copy)
@@ -396,7 +396,7 @@
(extends_array.Length() == num_type_params));
for (intptr_t i = 0; i < num_type_params; i++) {
type_extends = extends_array.TypeAt(i);
- if (!type_extends.IsVarType()) {
+ if (!type_extends.IsDynamicType()) {
type = arguments.TypeAt(offset + i);
if (type.IsInstantiated()) {
if (!type_extends.IsInstantiated()) {
@@ -496,10 +496,10 @@
// Copy the parsed type arguments at the correct offset in the full type
// argument vector.
const intptr_t offset = num_type_arguments - num_type_parameters;
- Type& type = Type::Handle(Type::VarType());
+ Type& type = Type::Handle(Type::DynamicType());
for (intptr_t i = 0; i < num_type_parameters; i++) {
// If no type parameters were provided, a raw type is desired, so we
// create a vector of VarType.
if (!arguments.IsNull()) {
type = arguments.TypeAt(i);
}
@@ -496,10 +496,10 @@
for (intptr_t i = 0; i < num_type_parameters; i++) {
// If no type parameters were provided, a raw type is desired, so we
- // create a vector of VarType.
+ // create a vector of DynamicType.
if (!arguments.IsNull()) {
type = arguments.TypeAt(i);
« no previous file with comments | « runtime/vm/ast_test.cc ('k') | runtime/vm/code_generator_ia32.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698